/*
 * Local Matters, Inc. Confidential
 * OCO Source Materials
 * (C) Local Matters, Inc. 2007. All Rights Reserved.
 */
package com.localmatters.flexiq.security;

import java.security.GeneralSecurityException;
import java.security.Key;
import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.spec.SecretKeySpec;

/**
 * A Blowfish cipher service implementation.
 *
 * @author Daniel Cavalcanti
 */
public class BlowfishCipherService
    extends CipherServiceBase
    implements CipherService {
    
    // **********************************************************************
    // Class constants
    // **********************************************************************
    
    /**
     * The string constant identity a Blowfish key in JCE.
     */
    public static final String BLOWFISH_KEY = "Blowfish";
    
    /**
     * The standard algorithm name for Blowfish.
     */
    public static final String BLOWFISH_CIPHER = "Blowfish";
    
    // **********************************************************************
    // Constructors
    // **********************************************************************
    
    /**
     * Creates a new instance of BlowfishCipherService
     */
    public BlowfishCipherService()
    throws GeneralSecurityException {
        cipher = Cipher.getInstance(BLOWFISH_CIPHER);
        keygen = KeyGenerator.getInstance(BLOWFISH_KEY);
        setKey(keygen.generateKey());
    }
    
    /**
     * Creates a new instance of BlowfishCipherService.
     * 
     * @param key The cipher key.
     * @throws java.security.GeneralSecurityException If cannot create cipher service.
     */
    public BlowfishCipherService(Key key)
    throws GeneralSecurityException {
        cipher = Cipher.getInstance(BLOWFISH_CIPHER);
        setKey(key);
    }
    
    // **********************************************************************
    // SecurityService methods
    // **********************************************************************

    public synchronized void importKey(byte[] key)
    throws GeneralSecurityException {
        this.key = new SecretKeySpec(key, BLOWFISH_KEY);
    }
    
}
