/*
 * Local Matters, Inc. Confidential
 * OCO Source Materials
 * (C) Local Matters, Inc. 2007. All Rights Reserved.
 */
package com.localmatters.flexiq.security;

import java.security.GeneralSecurityException;
import java.security.InvalidKeyException;
import java.security.Key;
import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.spec.SecretKeySpec;

/**
 * A DES cipher service implementation.
 * The cipher assumes the Eletronic Codebook mode and PKCS #5-style padding.
 *
 * @author Daniel Cavalcanti
 */
public class DESCipherService
    extends CipherServiceBase
    implements CipherService {
    
    // **********************************************************************
    // Class constants
    // **********************************************************************
    
    /**
     * The string constant identity a DES key in JCE.
     */
    public static final String DES_KEY = "DES";
    
    /**
     * The standard algorithm name for DES, the standard name for the
     * Electronic Codebook mode, and the standard name for PKCS #5-style
     * padding.
     */
    public static final String DES_CIPHER = "DES/ECB/PKCS5Padding";
    
    // **********************************************************************
    // Constructors
    // **********************************************************************
    
    /**
     * Creates a new instance of DESCipherService.
     *
     * @throws java.security.GeneralSecurityException If cannot create cipher service.
     */
    public DESCipherService()
    throws GeneralSecurityException {
        cipher = Cipher.getInstance(DES_CIPHER);
        keygen = KeyGenerator.getInstance(DES_KEY);
        setKey(keygen.generateKey());
    }
    
    /**
     * Creates a new instance of DESCipherService.
     * 
     * @param key The cipher key.
     * @throws java.security.GeneralSecurityException If cannot create cipher service.
     */
    public DESCipherService(Key key)
    throws GeneralSecurityException {
        cipher = Cipher.getInstance(DES_CIPHER);
        setKey(key);
    }
    
    // **********************************************************************
    // SecurityService methods
    // **********************************************************************
    
    public void importKey(byte[] key)
    throws GeneralSecurityException {
        this.key = new SecretKeySpec(key, DES_KEY);
    }
    
}
