/*
 * Local Matters, Inc. Confidential
 * OCO Source Materials
 * (C) Local Matters, Inc. 2007. All Rights Reserved.
 */
package com.localmatters.flexiq.security;

import java.security.GeneralSecurityException;
import java.security.Key;
import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.spec.SecretKeySpec;

/**
 * A Triple DES cipher service implementation.
 * The cipher assumes the Eletronic Codebook mode and PKCS #5-style padding.
 *
 * @author Daniel Cavalcanti
 */
public class TripleDESCipherService
    extends CipherServiceBase
    implements CipherService {
    
    // **********************************************************************
    // Class constants
    // **********************************************************************
    
    /**
     * The string constant identity a triple DES key in JCE.
     */
    public static final String TRIPLE_DES_KEY = "DESede";
    
    /**
     * The standard algorithm name for triple DES, the standard name for the
     * Electronic Codebook mode, and the standard name for PKCS #5-style
     * padding.
     */
    public static final String TRIPLE_DES_CIPHER = "DESede/ECB/PKCS5Padding";
    
    // **********************************************************************
    // Constructors
    // **********************************************************************
    
    /**
     * Creates a new instance of TripleDESCipherService.
     *
     * @throws java.security.GeneralSecurityException If cannot create cipher service.
     */
    public TripleDESCipherService()
    throws GeneralSecurityException {
        cipher = Cipher.getInstance(TRIPLE_DES_CIPHER);
        keygen = KeyGenerator.getInstance(TRIPLE_DES_KEY);
        setKey(keygen.generateKey());
    }
    
    /**
     * Creates a new instance of TripleDESCipherService.
     * 
     * @param key The cipher key.
     * @throws java.security.GeneralSecurityException If cannot create cipher service.
     */
    public TripleDESCipherService(Key key)
    throws GeneralSecurityException {
        cipher = Cipher.getInstance(TRIPLE_DES_CIPHER);
        setKey(key);
    }
    
    // **********************************************************************
    // SecurityService methods
    // **********************************************************************
    
    public void importKey(byte[] key)
    throws GeneralSecurityException {
        this.key = new SecretKeySpec(key, TRIPLE_DES_KEY);
    }
    
}
